
.. If you created a package, create one automodule per module in the package.

.. automodule:: adafruit_rgb_display.rgb
   :members:

.. automodule:: adafruit_rgb_display.hx8353
  :members:

.. automodule:: adafruit_rgb_display.ili9341
   :members:

.. automodule:: adafruit_rgb_display.s6d02a1
  :members:

.. automodule:: adafruit_rgb_display.ssd1331
   :members:

.. automodule:: adafruit_rgb_display.ssd1351
  :members:

.. automodule:: adafruit_rgb_display.st7735
  :members:

.. automodule:: adafruit_rgb_display.st7789
  :members:
